local VERSION = tonumber(("$Revision: 44260 $"):match("%d+"))

PartyToGo = AceLibrary("AceAddon-2.0"):new("AceEvent-2.0", "AceConsole-2.0", "AceDB-2.0")

function PartyToGo:OnInitialize()
	self:RegisterDB("PartyToGoDB")
	self:RegisterDefaults("profile", {
		announce = {
			objective = false,
			complete = false,
		},
		notify = {
			message = true,
			chat = false,
		},
	})
	self:RegisterChatCommand({"/p2g", "/partytogo",}, {
		name = "PartyToGo",
		desc = "Keep you up to date on your party's status, and them up to date on yours",
		type = "group",
		args = {
			announce = {
				name = "Announce",
				desc = "Announce quest status in party chat",
				type = "group",
				args = {
					complete = {
						type = 'toggle', name = "Announce completion",
						desc = "Announce when all a quests' objectives are completed",
						get = function() return self.db.profile.announce.complete end,
						set = function(t) self.db.profile.announce.complete = t end,
					},
					objective = {
						type = 'toggle', name = "Announce objectives",
						desc = "Announce when a quest objective is advanced",
						get = function() return self.db.profile.announce.objective end,
						set = function(t) self.db.profile.announce.objective = t end,
					},
				},
			},
			notify = {
				name = "Notify",
				desc = "Local announcements when people in your party complete an objective",
				type = "group",
				args = {
					message = {
						type = "toggle", name = "Messageframe",
						desc = "Show in the messageframe (like normal quest notifications)",
						get = function() return self.db.profile.notify.message end,
						set = function(t) self.db.profile.notify.message = t end,
					},
					chat = {
						type = "toggle", name = "Chat",
						desc = "Show in the chatframe",
						get = function() return self.db.profile.notify.chat end,
						set = function(t) self.db.profile.notify.chat = t end,
					},
				},
			},
		},
	})
end

function PartyToGo:OnEnable()
	self:RegisterEvent("Quixote_Party_Leaderboard_Update")
	self:RegisterEvent("Quixote_Leaderboard_Update")
	self:RegisterEvent("Quixote_Quest_Complete")
end

function PartyToGo:Quixote_Party_Leaderboard_Update(sender, title, description, numHad, numGot, numNeeded)
	local message
	if numGot == numNeeded then
		message = ("(%s:%s) %s"):format(sender,title,"completed")
	else
		message = ("(%s:%s) %s: %d/%d"):format(sender,title,description,numGot,numNeeded)
	end
	if self.db.profile.notify.message then
		UIErrorsFrame:AddMessage(message, 1.0, 1.0, 0.0, 1.0)
	end
	if self.db.profile.notify.chat then
		self:Print(message)
	end
end

function PartyToGo:Quixote_Leaderboard_Update(name, id, lid, desc, numHad, numGot, numNeeded)
	if self.db.profile.announce.objective and GetNumPartyMembers() > 0 then
		SendChatMessage(("%s - %s: %d/%d"):format(name, desc, numGot, numNeeded), "PARTY")
	end
end

function PartyToGo:Quixote_Quest_Complete(name, id)
	if self.db.profile.announce.complete and GetNumPartyMembers() > 0 then
		SendChatMessage(("%s %s"):format(name, L["completed"]), "PARTY")
	end
end